@@ -4,7 +4,7 @@ from TextPreprocessing.utility import process_text
 class preprocess:
     
     def __init__(self):
-        self.__version__ = "3.1.0"
+        self.__version__ = "3.1.1"
         self.obj = process_text()
         self.start = 1
     
@@ -14,12 +14,15 @@ class preprocess:
     def set_entity_ignore_list(self, ignore_list):
         self.obj.set_entity_exclusion_list(ignore_list)
 
+    def clean_entities(self, text):
+        return self.obj.clear_generic_entity(text)
+
 
     def cleanup(self, text, end):
         text = self.obj.clear_email_id(text)
         text = self.obj.clear_web_url(text)
         text = self.obj.clear_html_tags(text)
-        text = self.obj.clear_generic_entity(text)
+        
         text = str(text).lower().replace('\\', '').replace('_', ' ')
         text = self.obj.convert_abbreviations(text)
         text = self.obj.clear_binary_char(text)
